@@ -17,10 +17,10 @@
 #include <KItinerary/Event>
 #include <KItinerary/Flight>
 #include <KItinerary/JsonLdDocument>
-#include <KItinerary/RentalCar>
 #include <KItinerary/Organization>
 #include <KItinerary/Place>
 #include <KItinerary/Person>
+#include <KItinerary/RentalCar>
 #include <KItinerary/Reservation>
 #include <KItinerary/Taxi>
 #include <KItinerary/Ticket>
@@ -161,6 +161,15 @@ bool isSameSeat(const Seat &lhsSeat, const Seat &rhsSeat)
         const QRegularExpression rx(uR"([[:space:][:punct:]])"_s);
         auto lhsSet = lhsSeat.seatNumber().toCaseFolded().split(rx, Qt::SkipEmptyParts);
         auto rhsSet = rhsSeat.seatNumber().toCaseFolded().split(rx, Qt::SkipEmptyParts);
+
+        // remove full words, which are qualifiers like "window" or "aisle", which are meaningless for this
+        lhsSet.erase(std::remove_if(lhsSet.begin(), lhsSet.end(), [](const auto &s) {
+            return std::ranges::all_of(s, [](QChar c) { return c.isLetter(); });
+        }), lhsSet.end());
+        rhsSet.erase(std::remove_if(rhsSet.begin(), rhsSet.end(), [](const auto &s) {
+            return std::ranges::all_of(s, [](QChar c) { return c.isLetter(); });
+        }), rhsSet.end());
+
         std::ranges::sort(lhsSet);
         std::ranges::sort(rhsSet);
         return lhsSet == rhsSet;
@@ -224,6 +233,13 @@ bool MergeUtil::isSame(const QVariant& lhs, const QVariant& rhs)
         if (conflictIfPresent(lhsRes.reservationNumber(), rhsRes.reservationNumber()) || conflictIfPresent(lhsRes.passengerSequenceNumber(), rhsRes.passengerSequenceNumber())) {
             return false;
         }
+        // same single-leg IATA BCBP code is considered equivalent regardless of everything else
+        // this helps with merging extracted results from data with missing context dates
+        const auto lhsTicket = lhsRes.reservedTicket().value<Ticket>();
+        const auto rhsTicket = rhsRes.reservedTicket().value<Ticket>();
+        if (!lhsTicket.ticketToken().isEmpty() && lhsTicket.ticketTokenData().toString().startsWith("M1"_L1) && lhsTicket.ticketToken() == rhsTicket.ticketToken()) {
+            return true;
+        }
         return isSame(lhsRes.reservationFor(), rhsRes.reservationFor());
     }
     if (JsonLd::isA<Flight>(lhs)) {
@@ -527,6 +543,23 @@ static bool isSameLineName(const QString &lhs, const QString &rhs)
     );
 }
 
+[[nodiscard]] static bool isSameTrainType(QStringView lhs, QStringView rhs)
+{
+    qsizetype i = 0;
+    for (; i < lhs.size() && i < rhs.size(); ++i) {
+        if (lhs[i] != rhs[i]) {
+            break;
+        }
+    }
+
+    if (i == 0 || i == lhs.size() || i == rhs.size()) {
+        return false;
+    }
+
+    return std::ranges::all_of(lhs.mid(i), [](QChar c) { return c.isNumber(); })
+        && std::ranges::all_of(rhs.mid(i), [](QChar c) { return c.isNumber(); });
+}
+
 static bool isSameTrainTrip(const TrainTrip &lhs, const TrainTrip &rhs)
 {
     if (lhs.departureDay() != rhs.departureDay()) {
@@ -580,7 +613,19 @@ static bool isSameTrainTrip(const TrainTrip &lhs, const TrainTrip &rhs)
     qCDebug(CompareLog) << "left:" << lhs.trainName() << lhs.trainNumber() << lhs.departureTime();
     qCDebug(CompareLog) << "right:" << rhs.trainName() << rhs.trainNumber() << rhs.departureTime();
     qCDebug(CompareLog) << "same line:" << isSameLine;
-    return !conflictIfPresent(lhs.trainName(),rhs.trainName()) && isSameLine;
+    if (!conflictIfPresent(lhs.trainName(),rhs.trainName()) && isSameLine) {
+        return true;
+    }
+
+    // handle dividing trains, ie. train number might differ
+    if (isSameTrainType(lhs.trainNumber(), rhs.trainNumber()) && lhs.departureTime().isValid() && lhs.arrivalTime().isValid()) {
+        const auto depExact = LocationUtil::isSameLocation(lhs.departureStation(), rhs.departureStation(), LocationUtil::Exact);
+        const auto arrExact = LocationUtil::isSameLocation(lhs.arrivalStation(), rhs.arrivalStation(), LocationUtil::Exact);
+        qCDebug(CompareLog) << "possible dividing train" << depExact << arrExact;
+        return depExact && arrExact;
+    }
+
+    return false;
 }
 
 static bool isSameBusTrip(const BusTrip &lhs, const BusTrip &rhs)
@@ -918,6 +963,34 @@ QVariant MergeUtil::merge(const QVariant &lhs, const QVariant &rhs)
     return res;
 }
 
+QVariant MergeUtil::mergeIncidence(const QVariant &res, const QVariant &other)
+{
+    // special case for LodgingReservation, their time range is in the Reservation object
+    if (JsonLd::isA<LodgingReservation>(res)) {
+        const auto hotel = res.value<LodgingReservation>();
+        const auto otherHotel = other.value<LodgingReservation>();
+        auto out = hotel;
+        out.setCheckinTime(mergeValue(hotel.checkinTime(), otherHotel.checkinTime()));
+        out.setCheckoutTime(mergeValue(hotel.checkoutTime(), otherHotel.checkoutTime()));
+        out.setReservationFor(MergeUtil::merge(hotel.reservationFor(), otherHotel.reservationFor()));
+        return out;
+    }
+
+    if (JsonLd::isA<TrainReservation>(res) || JsonLd::isA<BusReservation>(res) || JsonLd::isA<BoatReservation>(res) || JsonLd::isA<FlightReservation>(res)) {
+        const auto trip = JsonLd::convert<Reservation>(res).reservationFor();
+        const auto otherTrip = JsonLd::convert<Reservation>(other).reservationFor();
+        auto out = res;
+        JsonLdDocument::writeProperty(out, "reservationFor", MergeUtil::merge(trip, otherTrip));
+        return out;
+    }
+
+    if (JsonLd::canConvert<Reservation>(res)) {
+        return res;
+    }
+
+    return merge(res, other);
+}
+
 bool isMinimalCancelationFor(const Reservation &res, const Reservation &cancel)
 {
     if (cancel.reservationStatus() != Reservation::ReservationCancelled) {
