@@ -17,7 +17,7 @@
 using namespace Qt::Literals::StringLiterals;
 using namespace KItinerary;
 
-Q_DECLARE_METATYPE(KItinerary::Internal::OwnedPtr<KMime::Content>)
+Q_DECLARE_METATYPE(KItinerary::Internal::OwnedPtr<const KMime::Content>)
 
 namespace {
 bool contentMightBeEmail(const QByteArray &data)
@@ -46,15 +46,6 @@ const T* findHeader(const KMime::Content *content)
     }
     return findHeader<T>(content->parent());
 }
-
-const KMime::Headers::Base* findHeader(const KMime::Content *content, const char *headerType)
-{
-    const auto header = content->headerByType(headerType);
-    if (header || !content->parent()) {
-        return header;
-    }
-    return findHeader(content->parent(), headerType);
-}
 }
 
 bool MimeDocumentProcessor::canHandleData(const QByteArray &encodedData, QStringView fileName) const
@@ -75,7 +66,7 @@ ExtractorDocumentNode MimeDocumentProcessor::createNodeFromData(const QByteArray
     msg->parse();
 
     ExtractorDocumentNode node;
-    node.setContent<Internal::OwnedPtr<KMime::Content>>(msg);
+    node.setContent<Internal::OwnedPtr<const KMime::Content>>(msg);
 
     const auto dateHdr = findHeader<KMime::Headers::Date>(msg);
     if (dateHdr) {
@@ -87,10 +78,18 @@ ExtractorDocumentNode MimeDocumentProcessor::createNodeFromData(const QByteArray
 
 ExtractorDocumentNode MimeDocumentProcessor::createNodeFromContent(const QVariant &decodedData) const
 {
-    auto *content = decodedData.value<KMime::Content*>();
+    auto *content = decodedData.value<const KMime::Content*>();
+    if (!content) {
+        content = decodedData.value<const KMime::Message*>();
+    }
+    // TODO eventually remove the non-const cases
+    if (!content) {
+        content = decodedData.value<KMime::Content*>();
+    }
     if (!content) {
         content = decodedData.value<KMime::Message*>();
     }
+
     if (!content) {
         return {};
     }
@@ -126,7 +125,7 @@ static ExtractorDocumentNode expandContentNode(ExtractorDocumentNode &node, cons
     } else if (content->bodyIsMessage()) {
         child = engine->documentNodeFactory()->createNode(QVariant::fromValue(content->bodyAsMessage().get()), u"message/rfc822");
     } else {
-        child = engine->documentNodeFactory()->createNode(content->decodedContent(), fileName);
+        child = engine->documentNodeFactory()->createNode(content->decodedBody(), fileName);
     }
     node.appendChild(child);
     return child;
@@ -142,13 +141,14 @@ static void expandContentNodeRecursive(ExtractorDocumentNode &node, const KMime:
     }
 
     // special handling of multipart/related to add images to the corresponding HTML document
-    if (ct && ct->isMultipart() && ct->isSubtype("related") && ct->parameter("type"_L1) == "text/html"_L1 && children.size() >= 2) {
-        const auto child = children.front();
-        if (child->contentType(false) && child->contentType(false)->isHTMLText()) {
+    if (ct && ct->isMultipart() && ct->isSubtype("related") && ct->parameter("type") == "text/html"_L1 && children.size() >= 2) {
+        const KMime::Content *child = children.front();
+        if (child->contentType() && child->contentType()->isHTMLText()) {
             auto htmlNode = expandContentNode(node, child, engine);
             for (auto it = std::next(children.begin()); it != children.end(); ++it) {
-                auto imgNode = expandContentNode(htmlNode, (*it), engine);
-                const auto cid = (*it)->contentID(false);
+                const KMime::Content *imgChild = *it;
+                auto imgNode = expandContentNode(htmlNode, imgChild, engine);
+                const auto cid = imgChild->contentID();
                 if (cid) {
                     imgNode.setLocation(cid->identifier());
                 }
@@ -168,18 +168,35 @@ static void expandContentNodeRecursive(ExtractorDocumentNode &node, const KMime:
 
 void MimeDocumentProcessor::expandNode(ExtractorDocumentNode &node, const ExtractorEngine *engine) const
 {
-    const auto content = node.content<KMime::Content*>();
+    const auto content = node.content<const KMime::Content*>();
     expandContentNodeRecursive(node, content, engine);
 }
 
+namespace {
+[[nodiscard]] bool matchHeader(const KMime::Content *content, QByteArrayView headerType, const ExtractorFilter &filter)
+{
+    if (!content) {
+        return false;
+    }
+    for (const auto &hdr : content->headers()) {
+        if (!hdr->is(headerType)) {
+            continue;
+        }
+        if (filter.matches(hdr->asUnicodeString())) {
+            return true;
+        }
+    }
+    return matchHeader(content->parent(), headerType, filter);
+}
+}
+
 bool MimeDocumentProcessor::matches(const ExtractorFilter &filter, const ExtractorDocumentNode &node) const
 {
-    const auto content = node.content<KMime::Content*>();
-    const auto header = findHeader(content, filter.fieldName().toUtf8().constData());
-    return header ? filter.matches(header->asUnicodeString()) : false;
+    const auto content = node.content<const KMime::Content*>();
+    return matchHeader(content, filter.fieldName().toUtf8(), filter);
 }
 
 void MimeDocumentProcessor::destroyNode(ExtractorDocumentNode &node) const
 {
-    destroyIfOwned<KMime::Content>(node);
+    destroyIfOwned<const KMime::Content>(node);
 }
