@@ -7,3 +7,10 @@ function extractFullImage(image, node)
 {
     return ExtractorEngine.extract(image, node.mimeType).result;
 }
+
+function promoteIcalEvent(event, node)
+{
+    let res = JsonLd.newEventReservation();
+    res.reservationFor = node.result[0];
+    return res;
+}
